@@ -19,9 +19,9 @@
 
 """Provides the FocusTrackingPresenter for Orca."""
 
-__id__        = "$Id: focus_tracking_presenter.py 2472 2007-06-13 22:05:48Z wwalker $"
-__version__   = "$Revision: 2472 $"
-__date__      = "$Date: 2007-06-13 18:05:48 -0400 (Wed, 13 Jun 2007) $"
+__id__        = "$Id: focus_tracking_presenter.py 2828 2007-09-13 19:26:33Z wwalker $"
+__version__   = "$Revision: 2828 $"
+__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -413,6 +413,17 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                          self._knownAppSettings[name].overrideAppKeyBindings( \
                             script, script.keyBindings)
 
+                    # Setup the user's application specific pronunciations
+                    # (if any).
+                    #
+                    if hasattr(self._knownAppSettings[name],
+                               "overridePronunciations"):
+                        script.overridePronunciations = \
+                            self._knownAppSettings[name].overridePronunciations
+                        script.app_pronunciation_dict = \
+                         self._knownAppSettings[name].overridePronunciations( \
+                            script, script.app_pronunciation_dict)
+
                     break
                 except ImportError:
                     debug.println(debug.LEVEL_FINEST,
@@ -501,7 +512,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         # generally do not like object:children-changed:remove events,
         # either.
         #
-        if event.type == "object:children-changed:remove":
+        if event.type.startswith("object:children-changed:remove"):
             if event.source == atspi.Accessible.makeAccessible(
                                    self.registry.desktop):
                 self._reclaimScripts()
@@ -524,7 +535,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             if (not debug.eventDebugFilter) \
                 or (debug.eventDebugFilter \
                     and debug.eventDebugFilter.match(event.type)):
-                debug.printDetails(debug.LEVEL_FINEST, "    ", event.source)
+                if not event.type.startswith("mouse:"):
+                    debug.printDetails(debug.LEVEL_FINEST, "    ", event.source)
 
         except CORBA.COMM_FAILURE:
             debug.printException(debug.LEVEL_WARNING)
@@ -559,7 +571,17 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         retryCount = 0
         oldLocusOfFocus = orca_state.locusOfFocus
         try:
-            s = self._getScript(event.source.app)
+            # If we've received a mouse event, then don't try to get
+            # event.source.app because the top most parent is of role 
+            # unknown, which will cause an ERROR message to be displayed.
+            # See Orca bug #409731 for more details.
+            #
+            if not event.type.startswith("mouse:"):
+                s = self._getScript(event.source.app)
+            else:
+                s = orca_state.activeScript
+            if not s:
+                return
         except:
             s = None
             debug.printException(debug.LEVEL_WARNING)
@@ -579,8 +601,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                     # in use, and then issues a focus: event on the
                     # main window, which is a frame.]]]
                     #
-                    if (event.type == "window:activate") \
-                       or ((event.type == "focus:") \
+                    if event.type.startswith("window:activate") \
+                       or (event.type.startswith("focus:") \
                            and (event.source.role == rolenames.ROLE_FRAME)):
 
                         # We'll let someone else decide if it's important
@@ -677,7 +699,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             # We ignore defunct objects and let the atspi module take
             # care of them for us.
             #
-            if (e.type == "object:state-changed:defunct"):
+            if e.type.startswith("object:state-changed:defunct"):
                 if settings.debugEventQueue:
                     self._enqueueEventCount -= 1
                 return
@@ -688,7 +710,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             # hierarchy, so we just ignore them and let the atspi
             # module take care of it for us.
             #
-            if e.type == "object:property-change:accessible-parent":
+            if e.type.startswith("object:property-change:accessible-parent"):
                 if settings.debugEventQueue:
                     self._enqueueEventCount -= 1
                 return
@@ -696,7 +718,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             # At this point in time, we only care when objects are
             # removed from the desktop.
             #
-            if (e.type == "object:children-changed:remove") \
+            if e.type.startswith("object:children-changed:remove") \
                 and (e.source != self.registry.desktop):
                 if settings.debugEventQueue:
                     self._enqueueEventCount -= 1
@@ -739,7 +761,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             if settings.debugEventQueue:
                 debug.println(debug.LEVEL_ALL,
                               "           ...put complete")
-            if not self._gidleId:
+            if settings.asyncMode and (not self._gidleId):
                 if settings.gilSleepTime:
                     time.sleep(settings.gilSleepTime)
                 self._gidleId = gobject.idle_add(self._dequeueEvent)
@@ -751,6 +773,10 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             if settings.debugEventQueue:
                 debug.println(debug.LEVEL_ALL,
                               "           ...released")
+
+            if not settings.asyncMode:
+                self._dequeueEvent()
+
         if settings.debugEventQueue:
             self._enqueueEventCount -= 1
 
