@@ -33,9 +33,9 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py 2573 2007-07-31 16:11:39Z richb $"
-__version__   = "$Revision: 2573 $"
-__date__      = "$Date: 2007-07-31 12:11:39 -0400 (Tue, 31 Jul 2007) $"
+__id__        = "$Id: script.py 2822 2007-09-12 16:11:37Z wwalker $"
+__version__   = "$Revision: 2822 $"
+__date__      = "$Date: 2007-09-12 12:11:37 -0400 (Wed, 12 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -230,7 +230,7 @@ class Script:
         - pronunciations: the dictionary of pronunciations for this script.
         """
 
-        return pronunciationDict
+        return pronunciations
 
     def getAppState(self):
         """Returns an object that can be passed to setAppState.  This
